@@ -1,7 +1,6 @@
-from .cve import cve
+from cve_lookup.cve import cve
 
 def main():
-    from .cve import cve
     import argparse
 
     parser = argparse.ArgumentParser(description='Look up a CVE.')
